@@ -253,7 +253,7 @@ class BitmexOrder:
         self.order_cancel(self.props[symbol]['stoploss_id'])
 
     def stoporder_cancel(self, symbol):
-        self.order_cancel(self.props[symbol]['stop_id'])
+        self.order_cancel(symbol, self.props[symbol]['stop_id'])
 
     def bracket_stop_order(self, symbol, orderQty, entry, sl, tp=0):
         try:
@@ -299,22 +299,19 @@ class BitmexOrder:
             print("Error placing market order.", e, flush=True)
 
     def modifiy_stop(self, symbol, newPrice):
-        if self.props[symbol]['wait_stop']:
-            try:
-                res = self.client.client.Order.Order_amend(
-                    orderID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
-                                                                                          newPrice)
-                ).result()
-                return res
-            except HTTPBadRequest as e:
-                if 'Invalid amend' in str(e):
-                    return 'noValChanged'
-                elif 'Invalid origClOrdID' in str(e):
-                    return 'invalidID'
-                else:
-                    return str(e)
-        else:
-            return False
+        try:
+            res = self.client.client.Order.Order_amend(
+                orderID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
+                                                                                        newPrice)
+            ).result()
+            return res
+        except HTTPBadRequest as e:
+            if 'Invalid amend' in str(e):
+                return 'noValChanged'
+            elif 'Invalid origClOrdID' in str(e):
+                return 'invalidID'
+            else:
+                return str(e)
 
     def close(self, symbol, qty=0):
         if not qty:
