@@ -51,7 +51,7 @@ class Lotus:
             return requests.get(self._api_endpoint, params=auth).json()
         except ValueError:
             print("Can't get signal on endpoint {} with token {}. Please make sure your token is the right one and endpoint is set correct."
-                  "It could also be that you are timed out because you try to access with multiple IP's. In this case wait 40 minutes and try again.".format(
+                  "It could also be that you are timed out because you try to access with multiple IP's. In this case wait 40 minutes to be able to access again.".format(
                       self._api_endpoint, self.settings.token))
             return False
 
@@ -69,7 +69,6 @@ class Lotus:
 
     def process_signals(self, start=False):
         ns = self.get_api_signal()  # new signals
-        print(ns, flush=True)
         if ns:
             for symbol in self.symbols:
                 entry = ns[symbol]['entry']
@@ -177,5 +176,5 @@ class Lotus:
             self.order.manage_entries(self.symbols)
             if datetime.datetime.now().minute % 30 == 0:
                 time.sleep(19 + self.rand_sec(start=3))
-                self.process_signals(self.symbols)
+                self.process_signals()
                 time.sleep(40)
